Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormattab <matthieu.aubry@gmail.com>2014-02-10 06:08:16 +0400
committermattab <matthieu.aubry@gmail.com>2014-02-10 06:08:16 +0400
commit8d156bd1c4e8ee85d14e8caa64661354cb88bd8f (patch)
tree12c0bc180a8a049de77af4954fe7a1c2c564e003 /plugins/Overlay
parent3f08274f5e03b31e62327784a30c96af413a38c9 (diff)
Refactor core Login to allow for clean LoginHttpAuth logic refs #514
Diffstat (limited to 'plugins/Overlay')
-rw-r--r--plugins/Overlay/API.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/Overlay/API.php b/plugins/Overlay/API.php
index 1416436e39..0862160ac1 100644
--- a/plugins/Overlay/API.php
+++ b/plugins/Overlay/API.php
@@ -114,15 +114,15 @@ class API extends \Piwik\Plugin\API
*
* use Piwik\Registry;
*
- * public function initAuthenticationObject($allowCookieAuthentication)
+ * public function initAuthenticationObject($activateCookieAuth)
* {
- * Registry::set('auth', new LDAPAuth($allowCookieAuthentication));
+ * Registry::set('auth', new LDAPAuth($activateCookieAuth));
* }
*
* @param bool $allowCookieAuthentication Whether authentication based on `$_COOKIE` values should
* be allowed.
*/
- Piwik::postEvent('Request.initAuthenticationObject', array($allowCookieAuthentication = true));
+ Piwik::postEvent('Request.initAuthenticationObject', array($activateCookieAuth = true));
$auth = \Piwik\Registry::get('auth');
$success = Access::getInstance()->reloadAccess($auth);
@@ -114,15 +114,15 @@ class API extends \Piwik\Plugin\API
* }
*
- * @param bool $allowCookieAuthentication Whether authentication based on `$_COOKIE` values should
+ * @param bool $activateCookieAuth Whether authentication based on `$_COOKIE` values should
* be allowed.
*/